@@ -1,10 +1,10 @@
-# $Id: Choice.pm,v 1.6 2005/05/22 17:03:21 peterhickman Exp $
-
 package Data::RandomPerson::Choice;
 
 use strict;
 use warnings;
 
+use List::Util::WeightedChoice qw(choose_weighted);
+
 sub new {
     my ($class) = @_;
 
@@ -16,14 +16,16 @@ sub add {
 
     $count ||= 1;
 
-    push @{ $self->{data} }, $value foreach ( 1 .. $count );
-    $self->{size} += $count;
+    push @{ $self->{data} }, $value;
+    push @{ $self->{weight} }, $count;
+    $self->{size}++;
 }
 
 sub add_list {
     my ( $self, @list ) = @_;
 
     push @{ $self->{data} }, @list;
+    push @{ $self->{weight} }, 1 for 1..scalar(@list);
     $self->{size} += scalar(@list);
 }
 
@@ -38,7 +40,7 @@ sub pick {
 
     die "No data has been added to the list" unless $self->{size};
 
-    return $self->{data}[ int( rand( $self->{size} ) ) ];
+    return choose_weighted($self->{data}, $self->{weight});
 }
 
 1;
@@ -49,10 +51,6 @@ __END__
 
 Data::RandomPerson::Choice - Select an element from a list in proportion
 
-=head1 VERSION
-
-This document refers to version 0.4 of Data::RandomPerson::Choice, released Sept 13th, 2005
-
 =head1 SYNOPSIS
 
   use Data::RandomPerson::Choice;
@@ -74,7 +72,7 @@ This document refers to version 0.4 of Data::RandomPerson::Choice, released Sept
 
 =head2 Overview
 
-A way of simply defining the probablity of a selection of values based 
+A way of simply defining the probability of a selection of values based
 on the ratio of the elements this add( 'this' ) adds one element to the
 list, the count argument of add defaults to 1. add( 'that', 11 ) adds
 another 11 elements to the list giving a total of 12. The chance of
@@ -86,7 +84,7 @@ You can add as many values as you like to the list.
 
 =over 4
 
-=item Data::RandomPerson::Choice->new( )
+=item Data::RandomPerson::Choice->new()
 
 Returns a Data::RandomPerson::Choice object.
 
@@ -104,7 +102,7 @@ Adds VALUE to the list COUNT times, if COUNT is omitted it will default to 1.
 
 Adds a LIST of items to the data
 
-=item size( )
+=item size()
 
 Returns the size of the list so far
 
@@ -114,10 +112,6 @@ Returns an element from the list.
 
 =back
 
-=head1 ENVIRONMENT
-
-Perl 5
-
 =head1 DIAGNOSTICS
 
 =over 4
@@ -128,24 +122,12 @@ This error will occur if you have called pick() before add() has been called.
 
 =back
 
-=head1 BUGS
-
-None so far
-
-=head1 FILES
-
-None
-
-=head1 SEE ALSO
-
-None
-
 =head1 AUTHOR
 
 Peter Hickman (peterhi@ntlworld.com)
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005, Peter Hickman. All rights reserved. This module is
+Copyright (c) 2005, Peter Hickman. This module is
 free software. It may be used, redistributed and/or modified under the
 same terms as Perl itself.
